{% extends "base.html" %}

{% comment %}
Copyright (c) 2020-2024 Alexander Todorov <atodorov@otb.bg>

Licensed under GNU Affero General Public License v3 or later (AGPLv3+)
https://www.gnu.org/licenses/agpl-3.0.html
{% endcomment %}

{% load i18n %}
{% load static %}

{% block head %}
    {{ form.media }}
{% endblock %}
{% block title %}
    {% trans "Invite users" %}
{% endblock %}


{% block contents %}
    <div class="container-fluid container-cards-pf">
        <form class="form-horizontal" action="{% url 'tcms_tenants:invite-users' %}" method="post">
        {% csrf_token %}

        {% for field in form %}
            <div class="form-group">
                <label class="col-md-1 col-lg-1" for="{{ field.name }}">{% trans "Email" %}</label>
                <div class="col-sm-4 col-md-4 col-lg-4" {% if field.errors %}has-error{% endif %}">
                    <input type="text" id="{{ field.name }}" name="{{ field.name }}" value="{{ field.value|default:'' }}" class="form-control">

                    {{ field.errors }}
                </div>
            </div>
        {% endfor %}
            <button type="submit" class="btn btn-default btn-lg">{% trans "Save" %}</button>
        </form>
    </div>
{% endblock %}
