{% comment %}
Copyright (c) 2022 Ivajlo Karabojkov <karabojkov@kitbg.com>
Copyright (c) 2022-2024 Alexander Todorov <atodorov@otb.bg>

Licensed under GNU Affero General Public License v3 or later (AGPLv3+)
https://www.gnu.org/licenses/agpl-3.0.html
{% endcomment %}

<a class="navbar-brand" href="/">
    {% if tenant_logo %}
    <img
        src="{{ tenant_logo.attachment_file.url }}"
        alt="{{ tenant_name }}"
        title="{{ tenant_name }}"
        style="max-height: 20px"
    />
    {% else %}
    <span>{{ tenant_name }}</span>
    {% endif %}
</a>
